#!/usr/bin/python3

"""This module is meant for the purpose of a recursive function which prints out list on indivdual lines on the screen.  It is meant for times were there may on may not be nested list."""

def print_lol(the_list,indent=False, space=0, screen=sys.stdout):

	"""The purpose for this function is to take an agrument "the_list", which can be any list.  Each data item in the provided list is printed out on the screen on seperate lines. A second argument "indent" allows users to choose weather or not to have there list indented.  The third arugment "space", helps to indent the list(s) to whatever depth a user might need"""
	for each_item in the_list:
		if isinstance(each_item, list):
			print_lol(each_item, indent, space+1, screen)
		else:
			if indent:
				for tab_stop in range(space, screen):
					print("\t", end = ' ', file=screen)
			print(each_item, file=screen)
